(function ($) {
$.Redactor.opts.langs['fi'] = {
	html: 'HTML',
	video: 'Lisää video',
	image: 'Lisää kuva',
	table: 'Taulukko',
	link: 'Linkki',
	link_insert: 'Lisää linkki',
	link_edit: 'Muokkaa linkkiä',
	unlink: 'Poista linkki',
	formatting: 'Tyylit',
	paragraph: 'Normaaliteksti',
	quote: 'Lainaus',
	code: 'Koodi',
	header1: 'Otsikko 1',
	header2: 'Otsikko 2',
	header3: 'Otsikko 3',
	header4: 'Otsikko 4',
	header5: 'Otsikko 5',
	bold:  'Lihavointi',
	italic: 'Kursivointi',
	fontcolor: 'Tekstin väri',
	backcolor: 'Taustaväri',
	unorderedlist: 'Luettelo luettelomerkein',
	orderedlist: 'Numeroitu luettelo',
	outdent: 'Vähennä sisennystä',
	indent: 'Lisää sisennystä',
	cancel: 'Peru',
	insert: 'Lisää',
	save: 'Tallenna',
	_delete: 'Poista',
	insert_table: 'Lisää taulukko',
	insert_row_above: 'Lisää rivi ylle',
	insert_row_below: 'Lisää rivi alle',
	insert_column_left: 'Lisää sarake vasemmalle',
	insert_column_right: 'Lisää sarake oikealle',
	delete_column: 'Poista sarake',
	delete_row: 'Poista rivi',
	delete_table: 'Poista taulukko',
	rows: 'Rivit',
	columns: 'Sarakkeet',
	add_head: 'Lisää otsikkorivi',
	delete_head: 'Poista otsikkorivi',
	title: 'Kuvateksti',
	image_position: 'Kuvan sijainti',
	none: 'oletus',
	left: 'vasen',
	right: 'oikea',
	image_web_link: 'Kuvan URL-osoite',
	text: 'Teksti',
	mailto: 'Sähköposti',
	web: 'URL-osoite',
	video_html_code: 'Videon upotuskoodi',
	file: 'Lisää tiedosto',
	upload: 'Lähetä',
	download: 'Lataa',
	choose: 'Valitse',
	or_choose: 'tai valitse',
	drop_file_here: 'Vedä ja pudota kuva tähän',
	align_left:	'Tasaa vasemmalle',
	align_center: 'Keskitä',
	align_right: 'Tasaa oikealle',
	align_justify: 'Tasaa molemmat reunat',
	horizontalrule: 'Lisää vaakaviiva',
	deleted: 'Poistettu',
	anchor: 'Ankkuri',
	link_new_tab: 'Avaa linkki uudessa välilehdessä',
	underline: 'Alleviivaa',
	alignment: 'Tasaus',
	filename: 'Nimi (valinnainen)',
	edit: 'Edit',
	center: 'Center'
};
})( jQuery );
