(function ($) {
$.Redactor.opts.langs['vi'] = {
	html: 'Xem HTML',
	video: 'Chèn Video...',
	image: 'Chèn hình ảnh...',
	table: 'Tạo bảng',
	link: 'Đường dẫn',
	link_insert: 'Thêm đường dẫn ...',
	link_edit: 'Edit link',
	unlink: 'Loại bỏ đường dẫn',
	formatting: 'Định dạng văn bản',
	paragraph: 'Đoạn văn',
	quote: 'Trích dẫn',
	code: 'Chèn mã',
	header1: 'Tiêu đề 1',
	header2: 'Tiêu đề 2',
	header3: 'Tiêu đề 3',
	header4: 'Tiêu đề 4',
	header5: 'Tiêu đề 5',
	bold:  'In đậm',
	italic: 'In nghiêng',
	fontcolor: 'Màu chữ',
	backcolor: 'Đánh dấu đoạn văn',
	unorderedlist: 'Sắp xếp theo danh sách',
	orderedlist: 'Sắp xếp theo thứ tự',
	outdent: 'Bỏ thụt đầu dòng',
	indent: 'Thụt đầu dòng',
	cancel: 'Hủy bỏ',
	insert: 'Chèn',
	save: 'Lưu lại',
	_delete: 'Xóa',
	insert_table: 'Chèn bảng...',
	insert_row_above: 'Thêm hàng bên trên',
	insert_row_below: 'Thêm hàng bên dưới',
	insert_column_left: 'Thêm cột trái',
	insert_column_right: 'Thêm cột phải',
	delete_column: 'Xóa cột',
	delete_row: 'Xóa hàng',
	delete_table: 'Xóa bảng',
	rows: 'Hàng',
	columns: 'Cột',
	add_head: 'Thêm tiêu đề bảng',
	delete_head: 'Xóa tiêu đề bảng',
	title: 'Tiêu đề',
	image_position: 'Vị trí',
	none: 'Không thay đổi',
	left: 'Trái',
	right: 'Phải',
	image_web_link: 'Đường dẫn link ảnh',
	text: 'Văn bản',
	mailto: 'Email',
	web: 'Đường dẫn',
	video_html_code: 'Mã nhúng video',
	file: 'Tập tin đính kèm...',
	upload: 'Tải lên',
	download: 'Tải xuống',
	choose: 'Lựa Chọn',
	or_choose: 'Chọn từ máy tính',
	drop_file_here: 'Kéo thả hình ảnh vào đây',
	align_left:	'Căn trái',
	align_center: 'Căn giữa',
	align_right: 'Căn phải',
	align_justify: 'Dàn đều trang',
	horizontalrule: 'Chèn thanh ngang',
	deleted: 'Xóa',
	anchor: 'Liên kết',
	link_new_tab: 'Open link in new tab',
	underline: 'Underline',
	alignment: 'Alignment',
	filename: 'Name (optional)',
	edit: 'Edit',
	center: 'Center'
};
})( jQuery );
