(function ($) {
$.Redactor.opts.langs['he'] = {
	html: 'HTML',
	video: 'הכנס וידאו...',
	image: 'הכנס תמונה...',
	table: 'טבלה',
	link: 'קישור',
	link_insert: 'הכנס קישור',
	link_edit: 'Edit link',
	unlink: 'הסרת קישור',
	formatting: 'עיצוב',
	paragraph: 'פסקה',
	quote: 'ציטוט',
	code: 'קוד',
	header1: 'כותרת 1',
	header2: 'כותרת 2',
	header3: 'כותרת 3',
	header4: 'כותרת 4',
	header5: 'כותרת 5',
	bold:  'מודגש',
	italic: 'מוטה',
	fontcolor: 'צבע גופן',
	backcolor: 'צבע רקע',
	unorderedlist: 'רשימת תבליטים',
	orderedlist: 'רשימה ממוספרת',
	outdent: 'הזחה החוצה',
	indent: 'הזחה פנימה',
	cancel: 'ביטול',
	insert: 'הכנס',
	save: 'שמור',
	_delete: 'מחק',
	insert_table: 'הכנס טבלה...',
	insert_row_above: 'הוסף שורה מעל',
	insert_row_below: 'הוסף שורה מתחת',
	insert_column_left: 'הוסף עמודה משמאל',
	insert_column_right: 'הוסף עמודה מימין',
	delete_column: 'מחק עמודה',
	delete_row: 'מחק שורה',
	delete_table: 'מחק טבלה',
	rows: 'שורות',
	columns: 'עמודות',
	add_head: 'הוסף Head',
	delete_head: 'מחק Head',
	title: 'כותרת',
	image_position: 'מיקום',
	none: 'ריק',
	left: 'שמאל',
	right: 'ימין',
	image_web_link: 'קישור תמונה',
	text: 'טקסט',
	mailto: 'דואר אלקטרוני',
	web: 'URL',
	video_html_code: 'קוד הטבעת וידאו',
	file: 'הכנס קובץ...',
	upload: 'טען',
	download: 'הורד',
	choose: 'בחר',
	or_choose: 'או בחר',
	drop_file_here: 'שחרר קובץ כאן',
	align_left:	'ישר טקסט לשמאל',
	align_center: 'מרכז טקסט',
	align_right: 'ישר טקסט לימין',
	align_justify: 'ישור דו צידי',
	horizontalrule: 'הכנס קו הפרדה אופקי',
	deleted: 'נמחק',
	anchor: 'עוגן',
	link_new_tab: 'פתח קישור בלשונית חדשה',
	underline: 'קו תחתון',
	alignment: 'יישור',
	filename: 'Name (optional)',
	edit: 'Edit',
	center: 'Center'
};
})( jQuery );
