(function ($) {
$.Redactor.opts.langs['el'] = {
	html: 'HTML',
	video: 'Εισαγωγή βίντεο...',
	image: 'Εισαγωγή εικόνας...',
	table: 'Πίνακας',
	link: 'Σύνδεσμος',
	link_insert: 'Εισαγωγή συνδέσμου...',
	link_edit: 'Τροποποίηση συνδέσμου',
	unlink: 'Ακύρωση συνδέσμου',
	formatting: 'Μορφοποίηση',
	paragraph: 'Παράγραφος',
	quote: 'Παράθεση',
	code: 'Κώδικας',
	header1: 'Κεφαλίδα 1',
	header2: 'Κεφαλίδα 2',
	header3: 'Κεφαλίδα 3',
	header4: 'Κεφαλίδα 4',
	header5: 'Κεφαλίδα 5',
	bold:  'Έντονα',
	italic: 'Πλάγια',
	fontcolor: 'Χρώμα γραμματοσειράς',
	backcolor: 'Χρώμα επισήμανσης κειμένου',
	unorderedlist: 'Κουκκίδες',
	orderedlist: 'Αρίθμηση',
	outdent: 'Μείωση εσοχής',
	indent: 'Αύξηση εσοχής',
	cancel: 'Ακύρωση',
	insert: 'Εισαγωγή',
	save: 'Αποθήκευση',
	_delete: 'Διαγραφή',
	insert_table: 'Εισαγωγή πίνακα...',
	insert_row_above: 'Προσθήκη γραμμής επάνω',
	insert_row_below: 'Προσθήκη γραμμής κάτω',
	insert_column_left: 'Προσθήκη στήλης αριστερά',
	insert_column_right: 'Προσθήκη στήλης δεξιά',
	delete_column: 'Διαγραφή στήλης',
	delete_row: 'Διαγραφή σειράς',
	delete_table: 'Διαγραφή πίνακα',
	rows: 'Γραμμές',
	columns: 'Στήλες',
	add_head: 'Προσθήκη κεφαλίδας',
	delete_head: 'Διαγραφή κεφαλίδας',
	title: 'Τίτλος',
	image_position: 'Θέση',
	none: 'Καμία',
	left: 'Αριστερά',
	right: 'Δεξιά',
	image_web_link: 'Υπερσύνδεσμος εικόνας',
	text: 'Κείμενο',
	mailto: 'Email',
	web: 'Διεύθυνση URL',
	video_html_code: 'Κώδικας ενσωμάτωσης βίντεο',
	file: 'Εισαγωγή αρχείου...',
	upload: 'Ανέβασμα',
	download: 'Κατέβασμα',
	choose: 'Επέλεξε',
	or_choose: 'ή επέλεξε',
	drop_file_here: 'Σύρατε αρχεία εδώ',
	align_left:	'Στοίχιση αριστερά',
	align_center: 'Στοίχιση στο κέντρο',
	align_right: 'Στοίχιση δεξιά',
	align_justify: 'Πλήρης στοίχιση',
	horizontalrule: 'Εισαγωγή οριζόντιας γραμμής',
	deleted: 'Διαγράφηκε',
	anchor: 'Άγκυρα',
	link_new_tab: 'Άνοιγμα συνδέσμου σε νέα καρτέλα',
	underline: 'Υπογράμμιση',
	alignment: 'Στοίχιση',
	filename: 'Όνομα (προαιρετικό)',
	edit: 'Τροποποίηση',
	center: 'Κέντρο',
};
})( jQuery );

