(function ($) {
$.Redactor.opts.langs['eo'] = {
	html: 'HTML', // substantive
	video: 'Enŝovu videon...', // imperative
	image: 'Enŝovu bildon...', // imperative
	table: 'Tabelo', // substantive
	link: 'Ligu', // imperative
	link_insert: 'Enŝovu ligilon ...', // imperative
	link_edit: 'Edit link',
	unlink: 'Malligu', // imperative
	formatting: 'Tekstaranĝo', // substantive
	paragraph: 'Paragrafo', // substantive
	quote: 'Citaĵo', // substantive
	code: 'Kodo', // substantive
	header1: 'Kapo 1', // substantive
	header2: 'Kapo 2', // substantive
	header3: 'Kapo 3', // substantive
	header4: 'Kapo 4', // substantive
	header5: 'Kapo 5', // substantive
	bold:  'Grasa', // adjective
	italic: 'Kursiva', // adjective
	fontcolor: 'Tipara koloro', // substantive
	backcolor: 'Fona koloro', // substantive
	unorderedlist: 'Malorda listo', // substantive
	orderedlist: 'Orda listo', // substantive
	outdent: 'Malkrommarĝenu', // imperative
	indent: 'Krommarĝenu', // imperative
	cancel: 'Rezignu', // imperative
	insert: 'Enŝovu', // imperative
	save: 'Konservu',	// imperative
	_delete: 'Forigu', // imperative
	insert_table: 'Enŝovu tabelon...', // imperative
	insert_row_above: 'Enŝovu vicon supren', // imperative
	insert_row_below: 'Enŝovu vicon malsupren', // imperative
	insert_column_left: 'Enŝovu kolumnon maldekstren', // imperative
	insert_column_right: 'Enŝovu kolumnon dekstren', // imperative
	delete_column: 'Forigu kolumnon', // imperative
	delete_row: 'Forigu vicon', // imperative
	delete_table: 'Forigu tabelon', // imperative
	rows: 'Vicoj', // substantive (plural)
	columns: 'Kolumnoj', // substantive (plural)
	add_head: 'Enŝovu kapon', // imperative
	delete_head: 'Forigu kapon', // imperative
	title: 'Titolo', // substantive
	image_position: 'Bildloko', // substantive
	none: 'Neniu', // determiner
	left: 'Maldekstra', // adjective
	right: 'Dekstra', // adjective
	image_web_link: 'Bilda hiperligilo', // substantive
	text: 'Teksto', // substantive
	mailto: 'Retpoŝto', // substantive
	web: 'URL', // substantive
	video_html_code: 'Videa enkorpigita kodo', // substantive
	file: 'Enŝovu dosieron...', // imperative
	upload: 'Alŝutu', // imperative
	download: 'Elŝutu', // imperative
	choose: 'Elektu', // imperative
	or_choose: 'Aŭ elektu', // imperative
	drop_file_here: 'Demetu dosieron ĉi tien', // imperative
	align_left:	'Ĝisrandigu maldekstren', // imperative
	align_center: 'Centrigu', // imperative
	align_right: 'Ĝisrandigu dekstren', // imperative
	align_justify: 'Ĝisrandigu', // imperative
	horizontalrule: 'Enŝovu horizontalan linion', // imperative
	fullscreen: 'Plenekrana', // adjective
	deleted: 'Foriga', // adjective
	anchor: 'Ankro', // substantive
	link_new_tab: 'Malfermu hiperligilon en novan langeton', // imperative
	underline: 'Substrekita', // adjective
	alignment: 'Ĝisrandigo', // substantive
	filename: 'Dosiernomo (fakultativa)', // substantive
	edit: 'Redaktu', // imperative
	center: 'Center'
};
})( jQuery );
