(function ($) {
$.Redactor.opts.langs['az'] = {
	html: 'HTML',
	video: 'Video əlavə...',
	image: 'Şəkil əlavə...',
	table: 'Cədvəl',
	link: 'Link',
	link_insert: 'Link əlavə...',
	link_edit: 'Edit link',
	unlink: 'Linki sil',
	formatting: 'Format',
	paragraph: 'Paraqraf',
	quote: 'Sitat',
	code: 'Kod',
	header1: 'Başlıq 1',
	header2: 'Başlıq 2',
	header3: 'Başlıq 3',
	header4: 'Başlıq 4',
	header5: 'Başlıq 5',
	bold:  'Qalın',
	italic: 'Kursiv',
	fontcolor: 'Yazı Rəngi',
	backcolor: 'Fon rəngi',
	unorderedlist: 'Sırasız List',
	orderedlist: 'Sıralı List',
	outdent: 'Abzası geri al',
	indent: 'Abzas',
	cancel: 'Ləğv et',
	insert: 'Əlavə et',
	save: 'Yadda saxla',
	_delete: 'Sil',
	insert_table: 'Cədvəl əlavə et...',
	insert_row_above: 'Yuxarıya sətir əlavə et',
	insert_row_below: 'Aşağıya sətir əlavə et',
	insert_column_left: 'Sola sütun əlavə et',
	insert_column_right: 'Sağa sütun əlavə et',
	delete_column: 'Sütunu sil',
	delete_row: 'Sətiri sil',
	delete_table: 'Cədvəli sil',
	rows: 'Sətirlər',
	columns: 'Sütunlar',
	add_head: 'Başlıq əlavə et',
	delete_head: 'Başlığı sil',
	title: 'Başlıq',
	image_position: 'Mövqe',
	none: 'Heç biri',
	left: 'Sol',
	right: 'Sağ',
	image_web_link: 'Şəklin Veb Link',
	text: 'Yazı',
	mailto: 'E-poçt',
	web: 'URL',
	video_html_code: 'Video Embed Kodu',
	file: 'Fayl əlavə et...',
	upload: 'Yüklə',
	download: 'Endir',
	choose: 'Seç',
	or_choose: 'Vəya seç',
	drop_file_here: 'Faylı buraya at',
	align_left:	'Yazıyı sola yanaşdır',
	align_center: 'Yazıyı ortala',
	align_right: 'Yazıyı sağa yanaşdır',
	align_justify: 'Yazının kənarlarını düzləşdir',
	horizontalrule: 'Üfuqi xətt əlavə et',
	deleted: 'Silindi',
	anchor: 'Anchor',
	link_new_tab: 'Linki yeni tabda aç',
	underline: 'Altıxətli',
	alignment: 'Düzləndirmə',
	filename: 'Name (optional)',
	edit: 'Edit',
	center: 'Center'
};
})( jQuery );