(function ($) {
$.Redactor.opts.langs['nl'] = {
	html: 'HTML',
	video: 'Video',
	image: 'Afbeelding',
	table: 'Tabel',
	link: 'Link',
	link_insert: 'Link invoegen...',
	link_edit: 'Edit link',
	unlink: 'Link ontkoppelen',
	formatting: 'Stijlen',
	paragraph: 'Paragraaf',
	quote: 'Citaat',
	code: 'Code',
	header1: 'Kop 1',
	header2: 'Kop 2',
	header3: 'Kop 3',
	header4: 'Kop 4',
	header5: 'Kop 5',
	bold:  'Vet',
	italic: 'Cursief',
	fontcolor: 'Tekstkleur',
	backcolor: 'Achtergrondkleur',
	unorderedlist: 'Ongeordende lijst',
	orderedlist: 'Geordende lijst',
	outdent: 'Uitspringen',
	indent: 'Inspringen',
	redo: 'Opnieuw maken',
	undo: 'Ongedaan maken',
	cut: 'Knippen',
	cancel: 'Annuleren',
	insert: 'Invoegen',
	save: 'Opslaan',
	_delete: 'Verwijderen',
	insert_table: 'Tabel invoegen',
	insert_row_above: 'Rij hierboven invoegen',
	insert_row_below: 'Rij hieronder invoegen',
	insert_column_left: 'Kolom links toevoegen',
	insert_column_right: 'Kolom rechts toevoegen',
	delete_column: 'Verwijder kolom',
	delete_row: 'Verwijder rij',
	delete_table: 'Verwijder tabel',
	rows: 'Rijen',
	columns: 'Kolommen',
	add_head: 'Titel toevoegen',
	delete_head: 'Titel verwijderen',
	title: 'Titel',
	image_position: 'Positie',
	none: 'geen',
	left: 'links',
	right: 'rechts',
	image_web_link: 'Afbeelding link',
	text: 'Tekst',
	mailto: 'Email',
	web: 'URL',
	video_html_code: 'Video embed code',
	file: 'Bestand',
	upload: 'Uploaden',
	download: 'Downloaden',
	choose: 'Kies',
	or_choose: 'Of kies',
	drop_file_here: 'Sleep bestand hier',
	align_left:	'Links uitlijnen',
	align_center: 'Centreren',
	align_right: 'Rechts uitlijnen',
	align_justify: 'Uitvullen',
	horizontalrule: 'Horizontale lijn',
	fullscreen: 'Volledig scherm',
	deleted: 'Verwijderd',
	anchor: 'Anker',
	link_new_tab: 'Open link in nieuw tabblad',
	underline: 'Onderstrepen',
	alignment: 'Uitlijning',
	filename: 'Naam (optioneel)',
	edit: 'Bewerk',
	center: 'Center'
};
})( jQuery );

