(function ($) {
$.Redactor.opts.langs['ko'] = {
	html: 'HTML',
	video: '비디오',
	image: '이미지',
	table: '표',
	link: '링크',
	link_insert: '링크 삽입',
	link_edit: '링크 편집',
	unlink: '링크 삭제',
	formatting: '스타일',
	paragraph: '단락',
	quote: '인용',
	code: '코드',
	header1: '헤더 1',
	header2: '헤더 2',
	header3: '헤더 3',
	header4: '헤더 4',
	header5: '헤더 5',
	bold:  '굵게',
	italic: '기울임꼴',
	fontcolor: '글자색',
	backcolor: '배경색',
	unorderedlist: '글머리기호',
	orderedlist: '번호매기기',
	outdent: '내어쓰기',
	indent: '들여쓰기',
	cancel: '취소',
	insert: '삽입',
	save: '저장',
	_delete: '삭제',
	insert_table: '표 삽입',
	insert_row_above: '열을 위에 추가',
	insert_row_below: '열을 아래에 추가',
	insert_column_left: '행을 왼쪽에 추가',
	insert_column_right: '행을 오른쪽에 추가',
	delete_column: '컬럼 삭제',
	delete_row: '행 삭제',
	delete_table: '표 삭제',
	rows: '행',
	columns: '열',
	add_head: '표 헤더 추가',
	delete_head: '표 헤더 체거',
	title: '제목',
	image_position: '이미지 위치',
	none: '없음',
	left: '왼쪽',
	right: '오른쪽',
	image_web_link: '이미지 링크',
	text: '텍스트',
	mailto: '메일',
	web: 'URL',
	video_html_code: '비디오 삽입(embed) 코드',
	file: '파일',
	upload: '업로드',
	download: '다운로드',
	choose: '선택',
	or_choose: '또는 선택',
	drop_file_here: '파일을 여기에 떨굼',
	align_left:	'왼쪽정렬',
	align_center: '가운데정렬',
	align_right: '오른쪽정렬',
	align_justify: '가지런히정렬',
	horizontalrule: '수평선',
	fullscreen: '전체화면',
	deleted: '취소선',
	anchor: '링크',
	link_new_tab: '새로운 탭에서 링크 열기',
	underline: '밑줄',
	alignment: '정렬',
	filename: '파일명 (선택)',
	edit: '편집',
	center: 'Center'
};
})( jQuery );