(function ($) {
$.Redactor.opts.langs['fa'] = {
	html: 'اچ تی ام ال',
	video: 'درج ویدیو...',
	image: 'درج تصویر',
	table: 'جدول',
	link: 'پیوند',
	link_insert: 'درج پیوند ...',
	link_edit: 'Edit link',
	unlink: 'از بین بردن پیوند',
	formatting: 'فالب بندی',
	paragraph: 'پراگراف',
	quote: 'نقل قول',
	code: 'کد',
	header1: 'سرامد 1',
	header2: 'سرامد 2',
	header3: 'سرامد 3',
	header4: 'سرامد 4',
	header5: 'سرامد 5',
	bold:  'درشت',
	italic: 'خمیده',
	fontcolor: 'رنگ قلم',
	backcolor: 'رنگ ضمینه',
	unorderedlist: 'فهرست نامرتب',
	orderedlist: 'فهرست مرتب شده',
	outdent: 'بیرو رفتگی',
	indent: 'تو رفتگی',
	cancel: 'انصراف',
	insert: 'درج',
	save: 'ذخیره',
	_delete: 'حذف',
	insert_table: 'درج جدول ..',
	insert_row_above: 'سطر جدید در بالا',
	insert_row_below: 'سطر جدید در پائین',
	insert_column_left: 'ستون جدید در سمت چپ',
	insert_column_right: 'ستون جدید در سمت راست',
	delete_column: 'حذف ستون',
	delete_row: 'حذف سطر',
	delete_table: 'حذف جدول',
	rows: 'سطرها',
	columns: 'ستونها',
	add_head: 'درج سر ستون ',
	delete_head: 'حذف سرستون',
	title: 'عنوان',
	image_position: 'موقعیت',
	none: 'هیچیک',
	left: 'چپ',
	right: 'راست',
	image_web_link: 'آدرس تصویر در اینترنت',
	text: 'متن',
	mailto: 'ایمیل',
	web: 'آدرس',
	video_html_code: 'کد نمایش ویدئو',
	file: 'درج فایل ....',
	upload: 'بارگزاری',
	download: 'بارگیری',
	choose: 'انتخاب کنید',
	or_choose: 'یا انتخاب کنید',
	drop_file_here: 'این فایل ها حذف شوند',
	align_left:	'چپ جین',
	align_center: 'وسط چین',
	align_right: 'راست چین',
	align_justify: 'کشیده',
	horizontalrule: 'درج خط جدا کننده',
	fullscreen: 'نمایش کامل',
	deleted: 'حذف شده',
	anchor: 'قلاب',
	link_new_tab: 'Open link in new tab',
	underline: 'Underline',
	alignment: 'Alignment',
	filename: 'Name (optional)',
	edit: 'Edit',
	center: 'Center'
};
})( jQuery );
