(function ($) {
$.Redactor.opts.langs['es_ar'] = {
	html: 'HTML',
	video: 'Video',
	image: 'Imágen',
	table: 'Tabla',
	link: 'Enlace',
	link_insert: 'Insertar enlace ...',
	link_edit: 'Edit link',
	unlink: 'Eliminar enlace',
	formatting: 'Estilos',
	paragraph: 'Párrafo',
	quote: 'Comillas',
	code: 'Código',
	header1: 'Cabecera 1',
	header2: 'Cabecera 2',
	header3: 'Cabecera 3',
	header4: 'Cabecera 4',
	header5: 'Cabecera 5',
	bold:  'Negrita',
	italic: 'Itálica',
	fontcolor: 'Color fuente',
	backcolor: 'Color fondo',
	unorderedlist: 'Lista sin orden',
	orderedlist: 'Lista ordenada',
	outdent: 'Disminuir sangría',
	indent: 'Aumentar sangría',
	cancel: 'Cancelar',
	insert: 'Agregar',
	save: 'Guardar',
	_delete: 'Eliminar',
	insert_table: 'Agregar tabla',
	insert_row_above: 'Agregar fila arriba',
	insert_row_below: 'Agregar fila debajo',
	insert_column_left: 'Agregar columna a la izquierda',
	insert_column_right: 'Agregar column a la derecha',
	delete_column: 'Eliminar columna',
	delete_row: 'Eliminar fila',
	delete_table: 'Eliminar tabla',
	rows: 'Filas',
	columns: 'Columnas',
	add_head: 'Agregar encabezado',
	delete_head: 'Eliminar encabezado',
	title: 'Título',
	image_position: 'Posición',
	none: 'ninguna',
	left: 'izquierda',
	right: 'derecha',
	image_web_link: 'Enlace de imagen web',
	text: 'Texto',
	mailto: 'Email',
	web: 'URL',
	video_html_code: 'Código embebido del video',
	file: 'Archivo',
	upload: 'Cargar',
	download: 'Descargar',
	choose: 'Seleccionar',
	or_choose: 'O seleccionar',
	drop_file_here: 'Soltar el archivo aquí',
	align_left:	'Alinear a la izquierda',
	align_center: 'Alinear al centro',
	align_right: 'Alinear a la derecha',
	align_justify: 'Justificar',
	horizontalrule: 'Trazo horizontal',
	fullscreen: 'Pantalla completa',
	deleted: 'Eliminado',
	anchor: 'Anclaje',
	link_new_tab: 'Abrir enlace en otra pestaña',
	underline: 'Underline',
	alignment: 'Alignment',
	filename: 'Name (optional)',
	edit: 'Edit',
	center: 'Center'
};
})( jQuery );
