(function ($) {
$.Redactor.opts.langs['ca'] = {
	html: 'HTML',
	video: 'Inserta Vídeo...',
	image: 'Inserta Imatge...',
	table: 'Taula',
	link: 'Enllaç',
	link_insert: 'Inserta Enllaç ...',
	link_edit: 'Edit link',
	unlink: 'Elimina enllaç',
	formatting: 'Formateja',
	paragraph: 'Paràgraf',
	quote: 'Cita',
	code: 'Codi',
	header1: 'Capçalera 1',
	header2: 'Capçalera 2',
	header3: 'Capçalera 3',
	header4: 'Capçalera 4',
	header5: 'Capçalera 5',
	bold:  'Negreta',
	italic: 'Cursiva',
	fontcolor: 'Color de la lletra',
	backcolor: 'Color del fons',
	unorderedlist: 'Llista sense ordenar',
	orderedlist: 'Llista ordenada',
	outdent: 'Treure indentació',
	indent: 'Indentar',
	cancel: 'Cancel·lar',
	insert: 'Insertar',
	save: 'Desar',
	_delete: 'Eliminar',
	insert_table: 'Insertar Taula...',
	insert_row_above: 'Insertar fila superior',
	insert_row_below: 'Insertar fila inferior',
	insert_column_left: 'Insertar columna a l\'esquerra',
	insert_column_right: 'Insertar columna a la dreta',
	delete_column: 'Eliminar Columna',
	delete_row: 'Eliminar Fila',
	delete_table: 'Eliminar Taula',
	rows: 'Files',
	columns: 'Columnes',
	add_head: 'Incloure capçalera',
	delete_head: 'Eliminar capçalera',
	title: 'Títol',
	image_position: 'Posició',
	none: 'Cap',
	left: 'Esquerra',
	right: 'Dreta',
	image_web_link: 'Enllaç web a imatge',
	text: 'Text',
	mailto: 'Direcció de correu',
	web: 'URL',
	video_html_code: 'Codi de vídeo inserit',
	file: 'Insertar Fitxer...',
	upload: 'Pujar',
	download: 'Descarregar',
	choose: 'Escull',
	or_choose: 'O escull',
	drop_file_here: 'Arrosega el fitxer fins aquí',
	align_left:	'Alinear a l\'esquerra',
	align_center: 'Alinear al centre',
	align_right: 'Alinear a la dreta',
	align_justify: 'Justificar',
	horizontalrule: 'Insertar línia horitzontal',
	deleted: 'Eliminar',
	anchor: 'Àncora',
	link_new_tab: 'Obrir enllaç en una nova pestanya',
	underline: 'Underline',
	alignment: 'Alignment',
	filename: 'Name (optional)',
	edit: 'Edit',
	center: 'Center'
};
})( jQuery );
